@@ -16,7 +16,7 @@ PECHAS_PATH = _mkdir(BASE_PATH / "pechas")
 PECHA_PREFIX = "P"
 N_SIG = 6  # no. of significant digits for pecha id
 
-GITHUB_ORG_URL = "https://github.com/OpenPecha"
+GITHUB_ORG_URL = "https://github.com/OpenPecha-data"
 
 # Work
 WORKS_REPO_NAME = "works"
