@@ -1,12 +1,12 @@
 import json
-from datetime import datetime
 from enum import Enum
-from typing import Dict, List, Optional, Union
+from typing import List, Optional
 
 from pydantic import BaseModel, validator
 
 from .annotations import *
-from .ids import get_pecha_id, get_uuid
+from .ids import get_uuid
+from .metadata import PechaMetadata
 
 
 class LayerEnum(Enum):
@@ -36,12 +36,6 @@ class LayerEnum(Enum):
     segment = "Segment"
 
 
-class InitialCreationEnum(Enum):
-    ocr = "ocr"
-    ebook = "ebook"
-    input = "input"
-
-
 def _get_annotation_class(layer_name: LayerEnum):
     """Maps LayerEnum to Annotation class"""
     if layer_name == LayerEnum.book_title:
@@ -137,32 +131,7 @@ class Layer(BaseModel):
             del self.annotations[annotation_id]
 
 
-class PechaMetaData(BaseModel):
-    id: str = None
-    initial_creation_type: InitialCreationEnum
-    source_metadata: Optional[Dict] = {}
-    created_at: datetime = None
-    last_modified_at: datetime = None
-    statistics: Dict[str, Union[int, float, str]] = {}
-    quality: Dict[str, Union[int, float]] = {}
-
-    @validator("id", pre=True, always=True)
-    def set_id(cls, v):
-        return v or get_pecha_id()
-
-    @validator("created_at", pre=True, always=True)
-    def set_created_date(cls, v):
-        return v or datetime.now()
-
-    @validator("last_modified_at", pre=True, always=True)
-    def set_last_modified_date(cls, v):
-        return v or datetime.now()
-
-    def update_last_modified_date(self):
-        self.last_modified_at = datetime.now()
-
-
 class SpanINFO(BaseModel):
     text: str
     layers: Dict[LayerEnum, List[BaseAnnotation]]
-    metadata: PechaMetaData
+    metadata: PechaMetadata
